@@ -1,18 +1,17 @@
 ## Copyright (C) 2009,2010,2011,2012 Philip Nienhuis <prnienhuis at users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [ @var{xls}, @var{rstatus} ] = oct2xls (@var{arr}, @var{xls})
@@ -20,7 +19,7 @@
 ## @deftypefnx {Function File} [ @var{xls}, @var{rstatus} ] = oct2xls (@var{arr}, @var{xls}, @var{wsh}, @var{range})
 ## @deftypefnx {Function File} [ @var{xls}, @var{rstatus} ] = oct2xls (@var{arr}, @var{xls}, @var{wsh}, @var{range}, @var{options})
 ##
-## Add data in 1D/2D CELL array @var{arr} into a range specified in
+## Add data in 1D/2D CELL array @var{arr} into a cell range specified in
 ## @var{range} in worksheet @var{wsh} in an Excel spreadsheet file
 ## pointed to in structure @var{xls}.
 ## Return argument @var{xls} equals supplied argument @var{xls} and is
@@ -29,8 +28,9 @@
 ## A subsequent call to xlsclose is needed to write the updated spreadsheet
 ## to disk (and -if needed- close the Excel or Java invocation).
 ##
-## @var{arr} can be any array type save complex. Mixed numeric/text arrays
-## can only be cell arrays.
+## @var{arr} can be any 1D or 2D array containing numerical or character
+## data (cellstr) except complex. Mixed numeric/text arrays can only be
+## cell arrays.
 ##
 ## @var{xls} must be a valid pointer struct created earlier by xlsopen.
 ##
@@ -93,8 +93,8 @@
 ## 2010-03-14 Updated help text section on java memory usage
 ## 2010-07-27 Added formula writing support (based on patch by Benjamin Lindner)
 ## 2010-08-01 Added check on input array size vs. spreadsheet capacity
-##     "      Changed argument topleft into range (now compatible with ML); the
-##     "      old argument version (just topleft cell) is still recognized, though
+##     ''     Changed argument topleft into range (now compatible with ML); the
+##     ''     old argument version (just topleft cell) is still recognized, though
 ## 2010-08014 Added char array conversion to 1x1 cell for character input arrays
 ## 2010-08-16 Added check on presence of output argument. Made wsh = 1 default
 ## 2010-08-17 Corrected texinfo ("topleft" => "range")
@@ -110,13 +110,16 @@
 ## 2012-01-26 Fixed "seealso" help string
 ## 2012-02-20 Fixed range parameter to be default empty string rather than empty numeral
 ## 2012-02-27 More range param fixes
+## 2012-03-07 Updated texinfo help text
+## 2012-05-22 Cast all numeric data in input array to double
 
-## Last script file update (incl. subfunctions): 2012-02-26
+## Last script file update (incl. subfunctions): 2012-05-21
 
 function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange='', spsh_opts=[])
 
 	if (nargin < 2) error ("oct2xls needs a minimum of 2 arguments."); endif
-	# Make sure input array is a cell array
+  
+	# Validate input array, make sure it is a cell array
 	if (isempty (obj))
 		warning ("Request to write empty matrix - ignored."); 
 		rstatus = 1;
@@ -130,6 +133,9 @@ function [ xls, rstatus ] = oct2xls (obj, xls, wsh=1, crange='', spsh_opts=[])
 		error ("oct2xls: input array neither cell nor numeric array");
 	endif
 	if (ndims (obj) > 2), error ("Only 2-dimensional arrays can be written to spreadsheet"); endif
+  # Cast all numerical values to double as spreadsheets only have double/boolean/text type
+  idx = cellfun (@isnumeric, obj, "UniformOutput", true);
+  obj(idx) = cellfun (@double, obj(idx), "UniformOutput", false);
 
 	# Check xls file pointer struct
 	test1 = ~isfield (xls, "xtype");
@@ -193,18 +199,18 @@ endfunction
 #===================================================================================
 ## Copyright (C) 2009,2010,2011,2012 by Philip Nienhuis <prnienhuis@users.sf.net>
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [@var{xlso}, @var{status}] = oct2com2xls (@var{obj}, @var{xlsi})
@@ -238,18 +244,18 @@ endfunction
 ## 2010-01-13 Removed an extraneous statement used for debugging 
 ##            I plan look at it when octave v.3.4 is about to arrive.
 ## 2010-08-01 Added checks for input array size vs check on capacity
-##     "      Changed topleft arg into range arg (just topleft still recognized)
-##     "      Some code cleanup
-##     "      Added option for formula input as text string
+##     ''     Changed topleft arg into range arg (just topleft still recognized)
+##     ''     Some code cleanup
+##     ''     Added option for formula input as text string
 ## 2010-08-01 Added range vs. array size vs. capacity checks
 ## 2010-08-03 Moved range checks and type array parsing to separate functions
 ## 2010-10-20 Bug fix removing new empty sheets in new workbook that haven't been 
 ##            created in the first place due to Excel setting (thanks Ian Journeaux)
-##     "      Changed range use in COM transfer call
+##     ''     Changed range use in COM transfer call
 ## 2010-10-21 Improved file change tracking (var xls.changed)
 ## 2010-10-24 Fixed bug introduced in above fix: for loops have no stride param,
-##     "      replaced by while loop
-##     "      Added check for "live" ActiveX server
+##     ''     replaced by while loop
+##     ''     Added check for "live" ActiveX server
 ## 2010-11-12 Moved ptr struct check into main func
 ## 2012-01-26 Fixed "seealso" help string
 ## 2012-02-27 Copyright strings updated
@@ -369,6 +375,7 @@ function [ xls, status ] = oct2com2xls (obj, xls, wsh, crange, spsh_opts)
 			# Prepare to move new sheet to right of the worksheet stack anyway
 			ws_cnt = xls.workbook.Worksheets.count;			# New count needed
 			# Find where Excel has left it. We have to, depends on Excel version :-(
+
 			ii = 1;
 			while ((ii < ws_cnt+1) && ~strcmp (sh.Name, xls.workbook.Worksheets(ii).Name) == 1)
 				++ii;
@@ -425,20 +432,19 @@ endfunction
 #====================================================================================
 
 ## Copyright (C) 2009,2010,2011,2012 Philip Nienhuis <prnienhuis at users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [ @var{xlso}, @var{rstatus} ] = oct2jpoi2xls ( @var{arr}, @var{xlsi})
@@ -482,6 +488,8 @@ endfunction
 ## 2011-11-19 Try-catch added to allow for changed method name for nr of worksheets
 ## 2012-01-26 Fixed "seealso" help string
 ## 2012-02-27 Copyright strings updated
+## 2012-05-21 "Double" cast added when writing numeric values
+## 2012-05-21 "Double" cast moved into main func oct2xls
 
 function [ xls, rstatus ] = oct2jpoi2xls (obj, xls, wsh, crange, spsh_opts)
 
@@ -573,7 +581,11 @@ function [ xls, rstatus ] = oct2jpoi2xls (obj, xls, wsh, crange, spsh_opts)
 				end_try_catch
 			else
 				cell = row.createCell (kk, typearr(ii,jj));
-				cell.setCellValue (obj{ii, jj});
+        if (isnumeric (obj{ii, jj}))
+          cell.setCellValue (obj{ii, jj});
+        else
+          cell.setCellValue (obj{ii, jj});
+        endif
 			endif
 		endfor
 	endfor
@@ -589,20 +601,19 @@ endfunction
 
 #====================================================================================
 ## Copyright (C) 2009,2010,2011,2012 Philip Nienhuis <prnienhuis at users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [ @var{xlso}, @var{rstatus} ] = oct2jxla2xls ( @var{arr}, @var{xlsi})
@@ -638,8 +649,8 @@ endfunction
 ##            Added check for valid file pointer struct
 ## 2010-08-01 Improved try-catch for formulas to enter wrong formulas as text strings
 ## 2010-08-01 Added range vs. array size vs. capacity checks
-##     "      Code cleanup
-##     "      Changed topleft arg into range arg (topleft version still recognized)
+##     ''     Code cleanup
+##     ''     Changed topleft arg into range arg (topleft version still recognized)
 ## 2010-08-03 Moved range checks and cell type parsing to separate routines
 ## 2010-08-11 Moved addcell() into try-catch as it is addCell which throws fatal errors
 ## 2010-10-20 Improved logic for tracking file changes (xls.changed 2 or 3); dropped
@@ -648,6 +659,8 @@ endfunction
 ## 2010-11-12 Moved ptr struct check into main func
 ## 2012-01-26 Fixed "seealso" help string
 ## 2012-02-27 Copyright strings updated
+## 2012-05-21 "Double" cast added when writing numeric values
+## 2012-05-21 "Double" cast moved into main func oct2xls
 
 function [ xls, rstatus ] = oct2jxla2xls (obj, xls, wsh, crange, spsh_opts)
 
@@ -771,20 +784,19 @@ endfunction
 
 
 ## Copyright (C) 2011 Philip Nienhuis <prnienhuis@users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [ @var{xlso}, @var{rstatus} ] = oct2oxs2xls ( @var{arr}, @var{xlsi})
@@ -885,7 +897,7 @@ function [ xls, rstatus ] = oct2oxs2xls (obj, xls, wsh, crange, spsh_opts)
 				sh.getCell(jj+trow-2, ii+lcol-2).setVal (obj{jj, ii});  # Addr.cnt = 0-based
 				changed = 1;
 			catch
-				# Cell not existant. Add cell
+				# Cell not existent. Add cell
 				if ~(typearr(jj, ii) == 5)
 					sh.add (obj{jj, ii}, jj+trow-2, ii+lcol-2);
 					changed = 1;
@@ -901,20 +913,19 @@ endfunction
 
 
 ## Copyright (C) 2011,2012 Philip Nienhuis <prnienhuis@users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## oct2uno2xls
 
@@ -926,6 +937,8 @@ endfunction
 ## 2012-02-25 Catch stray Java RuntimeException when deleting sheets
 ## 2012-02-26 Bug fix when adding sheets near L.994 (wrong if-else-end construct).
 ## 2012-02-27 Copyright strings updated
+## 2012-05-21 "Double" cast added when writing numeric values
+## 2012-05-21 "Double" cast moved into main func oct2xls
 
 function [ xls, rstatus ] = oct2uno2xls (c_arr, xls, wsh, crange, spsh_opts)
 
