@@ -1,23 +1,22 @@
 ## Copyright (C) 2009,2010,2011,2012 Philip Nienhuis <prnienhuis at users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [@var{filetype}] = odsfinfo (@var{filename} [, @var{reqintf}])
 ## @deftypefnx {Function File} [@var{filetype}, @var{sh_names}] = odsfinfo (@var{filename} [, @var{reqintf}])
-## Query an OpenOffice_org spreadsheet file @var{filename} (with .ods
+## Query an OpenOffice_org spreadsheet file @var{filename} (with ods
 ## suffix) for some info about its contents.
 ##
 ## If @var{filename} is a recognizable OpenOffice.org spreadsheet file,
@@ -75,7 +74,9 @@
 ## 2011-09-03 Normal return in case of no ODS support (empty ods struct)
 ## 2012-01-26 Fixed "seealso" help string
 ## 2012-02-25 Return occupied sheet ranges in output args
-##     ''     Improve echo of sheet names & ranges if interactive.
+##     ''     Improve echo of sheet names & ranges if interactive
+## 2012-03-01 Fix wrong cell refs in UNO section ("(..)" rather than "{..}"
+## 2012-06-08 Support for odfdom-0.8.8-incubator
 
 function [ filetype, sheetnames ] = odsfinfo (filename, reqintf=[])
 
@@ -95,7 +96,7 @@ function [ filetype, sheetnames ] = odsfinfo (filename, reqintf=[])
     if (strcmp (ods.xtype, 'OTK'))
       # Get contents and table (= sheet) stuff from the workbook
       odfcont = ods.workbook;    # Local copy just in case
-      if (strcmp (ods.odfvsn, '0.8.7'))
+      if (strcmp (ods.odfvsn, '0.8.7') || strfind (ods.odfvsn, "0.8.8"))
         xpath = ods.workbook.getXPath;
       else
         xpath = ods.app.getXPath;
@@ -159,13 +160,13 @@ function [ filetype, sheetnames ] = odsfinfo (filename, reqintf=[])
       for ii=1:nr_of_sheets
         [ tr, lr, lc, rc ] = getusedrange (ods, ii);
         if (onscreen) 
-          printf (sprintf("%s", sheetnames(ii)));  # () as it is a Java object
+          printf (sprintf("%s", sheetnames{ii}));  # () as it is a Java object
           if (tr)
             printf (sprintf ("%s (used range = %s:%s)", \
-            adj_str (1:(30 - length (sheetnames(ii)))), \
+            adj_str (1:(30 - length (sheetnames{ii}))), \
             calccelladdress (tr, lc), calccelladdress (lr, rc)));
           else
-            printf ("%s (empty)", adj_str(1:(30 - length (sheetnames(ii)))));
+            printf ("%s (empty)", adj_str(1:(30 - length (sheetnames{ii}))));
           endif
           printf ("\n");
         endif
