@@ -1,18 +1,17 @@
 ## Copyright (C) 2009,2010,2011,2012 Philip Nienhuis <prnienhuis at users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} [@var{numarr}, @var{txtarr}, @var{rawarr},  @var{limits}] = odsread (@var{filename})
@@ -20,12 +19,14 @@
 ## @deftypefnx {Function File} [@var{numarr}, @var{txtarr}, @var{rawarr}, @var{limits}] = odsread (@var{filename}, @var{wsh}, @var{range})
 ## @deftypefnx {Function File} [@var{numarr}, @var{txtarr}, @var{rawarr}, @var{limits}] = odsread (@var{filename}, @var{wsh}, @var{range}, @var{reqintf})
 ##
-## Read data contained in range @var{range} from worksheet @var{wsh}
+## Read data contained from cell range @var{range} in worksheet @var{wsh}
 ## in OpenOffice_org Calc spreadsheet file @var{filename}.
 ##
 ## You need the octave-forge java package (> 1.2.6) and one or both of
-## jopendocument-<version>.jar or preferrably: (odfdom.jar (version 0.7.5
-#3 or 0.8.6) & xercesImpl.jar) in your javaclasspath.
+## jopendocument-<version>.jar or preferrably: (odfdom.jar (versions
+## 0.7.5 or 0.8.6+) & xercesImpl.jar v. 2.9.1) in your javaclasspath.
+## There is also experimental support invoking OpenOffice.org or clones
+## through Java/UNO bridge.
 ##
 ## Return argument @var{numarr} contains the numeric data, optional
 ## return arguments @var{txtarr} and @var{rawarr} contain text strings
@@ -59,8 +60,8 @@
 ##
 ## The optional last argument @var{reqintf} can be used to override 
 ## the automatic selection by odsread of one interface out of the
-## supported ones: Java/ODFtoolkit ('OTK') or Java/jOpenDocument 
-## ('JOD').
+## supported ones: Java/ODFtoolkit ('OTK'), Java/jOpenDocument 
+## ('JOD') or Java/UNO bridge ('UNO').
 ##
 ## Erroneous data and empty cells are set to NaN in @var{numarr} and
 ## turn up empty in @var{txtarr} and @var{rawarr}. Date/time values
@@ -116,30 +117,32 @@
 ## 2011-09-08 Catch empty ods structs after failed odsopen attempts
 ## 2011-09-18 Return empty output arg in case of empty rawarr
 ## 2012-01-26 Fixed "seealso" help string
+## 2012-03-07 Updated texinfo help text
+## 2012-06-08 Tabs replaced by double space
 
 function [ numarr, txtarr, rawarr, lim ] = odsread (filename, wsh=1, datrange=[], reqintf=[])
 
-	if (nargin < 1 || isempty (findstr ('.ods', tolower (filename))))
-		usage ("odsread: at least a filename incl. suffix is needed");
-	endif
-	if (nargout < 1)
-		usage ("odsread: no output argument(s) specified");
-	endif
+  if (nargin < 1 || isempty (findstr ('.ods', tolower (filename))))
+    usage ("odsread: at least a filename incl. suffix is needed");
+  endif
+  if (nargout < 1)
+    usage ("odsread: no output argument(s) specified");
+  endif
 
-	ods = odsopen (filename, 0, reqintf);
+  ods = odsopen (filename, 0, reqintf);
   
   if (~isempty (ods))
 
-  	[rawarr, ods, rstatus] = ods2oct (ods, wsh, datrange);
+    [rawarr, ods, rstatus] = ods2oct (ods, wsh, datrange);
 
-	  if (rstatus)
-		  [numarr, txtarr, lim] = parsecell (rawarr, ods.limits);
-	  else
-		  warning (sprintf ("No data read from %s.", filename));
+    if (rstatus)
+      [numarr, txtarr, lim] = parsecell (rawarr, ods.limits);
+    else
+      warning (sprintf ("No data read from %s.", filename));
       numarr = [];
-  	endif
-	
-	  ods = odsclose (ods);
+    endif
+  
+    ods = odsclose (ods);
 
   endif
 
