@@ -1,26 +1,25 @@
 ## Copyright (C) 2009,2010,2011,2012 Philip Nienhuis <pr.nienhuis at users.sf.net>
-## 
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
-## 
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-## 
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} @var{rstatus} = odswrite (@var{filename}, @var{arr})
 ## @deftypefnx {Function File} @var{rstatus} = odswrite (@var{filename}, @var{arr}, @var{wsh})
 ## @deftypefnx {Function File} @var{rstatus} = odswrite (@var{filename}, @var{arr}, @var{wsh}, @var{range})
 ## @deftypefnx {Function File} @var{rstatus} = odswrite (@var{filename}, @var{arr}, @var{wsh}, @var{range}, @var{reqintf})
-## Add data in 1D/2D array @var{arr} to sheet @var{wsh} in
-## OpenOffice_org Calc spreadsheet file @var{filename} in range @var{range}.
+## Add data in 1D/2D array @var{arr} into sheet @var{wsh} in
+## OpenOffice_org Calc spreadsheet file @var{filename} in cell range @var{range}.
 ##
 ## @var{rstatus} returns 1 if write succeeded, 0 otherwise.
 ##
@@ -28,8 +27,9 @@
 ## file name extension). If @var{filename} does not contain any directory
 ## path, the file is saved in the current directory.
 ##
-## @var{arr} can be any array type save complex. Mixed numeric/text arrays
-## can only be cell arrays.
+## @var{arr} can be any 1D or 2D array containing numerical or character
+## data (cellstr) except complex. Mixed numeric/text arrays can only be
+## cell arrays.
 ##
 ## @var{wsh} can be a number or string. In case of a not yet existing
 ## OpenOffice.org spreadsheet, the first sheet will be used & named
@@ -48,7 +48,8 @@
 ## Array @var{arr} will be clipped at the right and/or bottom if its size
 ## is bigger than can be accommodated in @var{range}.
 ## If @var{arr} is smaller than the @var{range} allows, it is placed
-## in the top left of @var{range}.
+## in the top left rectangle of @var{range} and cell values outside that
+## rectangle will be untouched.
 ##
 ## If @var{range} contains merged cells, only the elements of @var{arr}
 ## corresponding to the top or left Calc cells of those merged cells
@@ -92,29 +93,31 @@
 ## 2011-09-08 Minor filename error text adaptation
 ## 2012-01-26 Fixed "seealso" help string
 ## 2012-02-20 Fixed range parameter to be default empty string rather than empty numeral
+## 2010-03-07 Updated texinfo help text
+## 2012-06-08 Tabs replaced by double space
 
 function [ rstatus ] = odswrite (filename, data, wsh=1, crange='', reqintf=[])
 
-	# Input validity checks
-	if (nargin < 2)
-		usage ("Insufficient arguments - see 'help odswrite'");
-	elseif (~ischar (filename) || isempty (findstr ('.ods', tolower (filename))))
-		error ("First argument must be a filename (incl. .ods suffix for OTK & JOD)");
-	endif
+  # Input validity checks
+  if (nargin < 2)
+    usage ("Insufficient arguments - see 'help odswrite'");
+  elseif (~ischar (filename) || isempty (findstr ('.ods', tolower (filename))))
+    error ("First argument must be a filename (incl. .ods suffix for OTK & JOD)");
+  endif
 
-	ods = odsopen (filename, 1, reqintf);
+  ods = odsopen (filename, 1, reqintf);
 
-	if (~isempty (ods)) 
-		[ods, rstatus] = oct2ods (data, ods, wsh, crange);
+  if (~isempty (ods)) 
+    [ods, rstatus] = oct2ods (data, ods, wsh, crange);
 
-		# If rstatus was not OK, reset change indicator in ods pointer
-		if (~rstatus)
-			ods.changed = rstatus;
-			warning ("odswrite: data transfer errors, file not rewritten");
-		endif
+    # If rstatus was not OK, reset change indicator in ods pointer
+    if (~rstatus)
+      ods.changed = rstatus;
+      warning ("odswrite: data transfer errors, file not rewritten");
+    endif
 
-		ods = odsclose (ods);
+    ods = odsclose (ods);
 
-	endif
+  endif
 
 endfunction
